/* [config]
 * expect_result: pass
 * glsl_version: 1.30
 * require_extensions: AMD_shader_trinary_minmax
 * [end config]
 *
 * Check that the following test vectors are constant folded correctly:
 * max3(uvec4(0u, 0u, 0u, 0u), uvec4(0u, 0u, 0u, 0u), uvec4(0u, 1u, 2u, 5u)) => uvec4(0u, 1u, 2u, 5u)
 * max3(uvec4(0u, 0u, 0u, 0u), uvec4(0u, 1u, 1u, 1u), uvec4(34u, 0u, 1u, 2u)) => uvec4(34u, 1u, 1u, 2u)
 * max3(uvec4(0u, 0u, 0u, 0u), uvec4(1u, 1u, 2u, 2u), uvec4(5u, 34u, 0u, 1u)) => uvec4(5u, 34u, 2u, 2u)
 * max3(uvec4(0u, 0u, 0u, 0u), uvec4(2u, 2u, 2u, 5u), uvec4(2u, 5u, 34u, 0u)) => uvec4(2u, 5u, 34u, 5u)
 * max3(uvec4(0u, 0u, 0u, 0u), uvec4(5u, 5u, 5u, 5u), uvec4(1u, 2u, 5u, 34u)) => uvec4(5u, 5u, 5u, 34u)
 * max3(uvec4(0u, 0u, 0u, 0u), uvec4(34u, 34u, 34u, 34u), uvec4(0u, 1u, 2u, 5u)) => uvec4(34u, 34u, 34u, 34u)
 * max3(uvec4(0u, 1u, 1u, 1u), uvec4(34u, 0u, 0u, 0u), uvec4(34u, 0u, 1u, 2u)) => uvec4(34u, 1u, 1u, 2u)
 * max3(uvec4(1u, 1u, 1u, 1u), uvec4(0u, 0u, 1u, 1u), uvec4(5u, 34u, 0u, 1u)) => uvec4(5u, 34u, 1u, 1u)
 * max3(uvec4(1u, 1u, 1u, 1u), uvec4(1u, 1u, 1u, 2u), uvec4(2u, 5u, 34u, 0u)) => uvec4(2u, 5u, 34u, 2u)
 * max3(uvec4(1u, 1u, 1u, 1u), uvec4(2u, 2u, 2u, 2u), uvec4(1u, 2u, 5u, 34u)) => uvec4(2u, 2u, 5u, 34u)
 * max3(uvec4(1u, 1u, 1u, 1u), uvec4(5u, 5u, 5u, 5u), uvec4(0u, 1u, 2u, 5u)) => uvec4(5u, 5u, 5u, 5u)
 * max3(uvec4(1u, 1u, 1u, 1u), uvec4(5u, 34u, 34u, 34u), uvec4(34u, 0u, 1u, 2u)) => uvec4(34u, 34u, 34u, 34u)
 * max3(uvec4(1u, 1u, 2u, 2u), uvec4(34u, 34u, 0u, 0u), uvec4(5u, 34u, 0u, 1u)) => uvec4(34u, 34u, 2u, 2u)
 * max3(uvec4(2u, 2u, 2u, 2u), uvec4(0u, 0u, 0u, 1u), uvec4(2u, 5u, 34u, 0u)) => uvec4(2u, 5u, 34u, 2u)
 * max3(uvec4(2u, 2u, 2u, 2u), uvec4(1u, 1u, 1u, 1u), uvec4(1u, 2u, 5u, 34u)) => uvec4(2u, 2u, 5u, 34u)
 * max3(uvec4(2u, 2u, 2u, 2u), uvec4(2u, 2u, 2u, 2u), uvec4(0u, 1u, 2u, 5u)) => uvec4(2u, 2u, 2u, 5u)
 * max3(uvec4(2u, 2u, 2u, 2u), uvec4(2u, 5u, 5u, 5u), uvec4(34u, 0u, 1u, 2u)) => uvec4(34u, 5u, 5u, 5u)
 * max3(uvec4(2u, 2u, 2u, 2u), uvec4(5u, 5u, 34u, 34u), uvec4(5u, 34u, 0u, 1u)) => uvec4(5u, 34u, 34u, 34u)
 * max3(uvec4(2u, 2u, 2u, 5u), uvec4(34u, 34u, 34u, 0u), uvec4(2u, 5u, 34u, 0u)) => uvec4(34u, 34u, 34u, 5u)
 * max3(uvec4(5u, 5u, 5u, 5u), uvec4(0u, 0u, 0u, 0u), uvec4(1u, 2u, 5u, 34u)) => uvec4(5u, 5u, 5u, 34u)
 * max3(uvec4(5u, 5u, 5u, 5u), uvec4(1u, 1u, 1u, 1u), uvec4(0u, 1u, 2u, 5u)) => uvec4(5u, 5u, 5u, 5u)
 * max3(uvec4(5u, 5u, 5u, 5u), uvec4(1u, 2u, 2u, 2u), uvec4(34u, 0u, 1u, 2u)) => uvec4(34u, 5u, 5u, 5u)
 * max3(uvec4(5u, 5u, 5u, 5u), uvec4(2u, 2u, 5u, 5u), uvec4(5u, 34u, 0u, 1u)) => uvec4(5u, 34u, 5u, 5u)
 * max3(uvec4(5u, 5u, 5u, 5u), uvec4(5u, 5u, 5u, 34u), uvec4(2u, 5u, 34u, 0u)) => uvec4(5u, 5u, 34u, 34u)
 * max3(uvec4(5u, 5u, 5u, 5u), uvec4(34u, 34u, 34u, 34u), uvec4(1u, 2u, 5u, 34u)) => uvec4(34u, 34u, 34u, 34u)
 * max3(uvec4(34u, 34u, 34u, 34u), uvec4(0u, 0u, 0u, 0u), uvec4(0u, 1u, 2u, 5u)) => uvec4(34u, 34u, 34u, 34u)
 * max3(uvec4(34u, 34u, 34u, 34u), uvec4(0u, 1u, 1u, 1u), uvec4(34u, 0u, 1u, 2u)) => uvec4(34u, 34u, 34u, 34u)
 * max3(uvec4(34u, 34u, 34u, 34u), uvec4(1u, 1u, 2u, 2u), uvec4(5u, 34u, 0u, 1u)) => uvec4(34u, 34u, 34u, 34u)
 * max3(uvec4(34u, 34u, 34u, 34u), uvec4(2u, 2u, 2u, 5u), uvec4(2u, 5u, 34u, 0u)) => uvec4(34u, 34u, 34u, 34u)
 * max3(uvec4(34u, 34u, 34u, 34u), uvec4(5u, 5u, 5u, 5u), uvec4(1u, 2u, 5u, 34u)) => uvec4(34u, 34u, 34u, 34u)
 * max3(uvec4(34u, 34u, 34u, 34u), uvec4(34u, 34u, 34u, 34u), uvec4(0u, 1u, 2u, 5u)) => uvec4(34u, 34u, 34u, 34u)
 * max3(uvec4(34u, 0u, 0u, 0u), uvec4(34u, 0u, 0u, 0u), uvec4(34u, 0u, 1u, 2u)) => uvec4(34u, 0u, 1u, 2u)
 */
#version 130
#extension GL_AMD_shader_trinary_minmax : require

void main()
{
  float[all(equal(max3(uvec4(0u, 0u, 0u, 0u), uvec4(0u, 0u, 0u, 0u), uvec4(0u, 1u, 2u, 5u)), uvec4(0u, 1u, 2u, 5u))) ? 1 : -1] array0;
  float[all(equal(max3(uvec4(0u, 0u, 0u, 0u), uvec4(0u, 1u, 1u, 1u), uvec4(34u, 0u, 1u, 2u)), uvec4(34u, 1u, 1u, 2u))) ? 1 : -1] array1;
  float[all(equal(max3(uvec4(0u, 0u, 0u, 0u), uvec4(1u, 1u, 2u, 2u), uvec4(5u, 34u, 0u, 1u)), uvec4(5u, 34u, 2u, 2u))) ? 1 : -1] array2;
  float[all(equal(max3(uvec4(0u, 0u, 0u, 0u), uvec4(2u, 2u, 2u, 5u), uvec4(2u, 5u, 34u, 0u)), uvec4(2u, 5u, 34u, 5u))) ? 1 : -1] array3;
  float[all(equal(max3(uvec4(0u, 0u, 0u, 0u), uvec4(5u, 5u, 5u, 5u), uvec4(1u, 2u, 5u, 34u)), uvec4(5u, 5u, 5u, 34u))) ? 1 : -1] array4;
  float[all(equal(max3(uvec4(0u, 0u, 0u, 0u), uvec4(34u, 34u, 34u, 34u), uvec4(0u, 1u, 2u, 5u)), uvec4(34u, 34u, 34u, 34u))) ? 1 : -1] array5;
  float[all(equal(max3(uvec4(0u, 1u, 1u, 1u), uvec4(34u, 0u, 0u, 0u), uvec4(34u, 0u, 1u, 2u)), uvec4(34u, 1u, 1u, 2u))) ? 1 : -1] array6;
  float[all(equal(max3(uvec4(1u, 1u, 1u, 1u), uvec4(0u, 0u, 1u, 1u), uvec4(5u, 34u, 0u, 1u)), uvec4(5u, 34u, 1u, 1u))) ? 1 : -1] array7;
  float[all(equal(max3(uvec4(1u, 1u, 1u, 1u), uvec4(1u, 1u, 1u, 2u), uvec4(2u, 5u, 34u, 0u)), uvec4(2u, 5u, 34u, 2u))) ? 1 : -1] array8;
  float[all(equal(max3(uvec4(1u, 1u, 1u, 1u), uvec4(2u, 2u, 2u, 2u), uvec4(1u, 2u, 5u, 34u)), uvec4(2u, 2u, 5u, 34u))) ? 1 : -1] array9;
  float[all(equal(max3(uvec4(1u, 1u, 1u, 1u), uvec4(5u, 5u, 5u, 5u), uvec4(0u, 1u, 2u, 5u)), uvec4(5u, 5u, 5u, 5u))) ? 1 : -1] array10;
  float[all(equal(max3(uvec4(1u, 1u, 1u, 1u), uvec4(5u, 34u, 34u, 34u), uvec4(34u, 0u, 1u, 2u)), uvec4(34u, 34u, 34u, 34u))) ? 1 : -1] array11;
  float[all(equal(max3(uvec4(1u, 1u, 2u, 2u), uvec4(34u, 34u, 0u, 0u), uvec4(5u, 34u, 0u, 1u)), uvec4(34u, 34u, 2u, 2u))) ? 1 : -1] array12;
  float[all(equal(max3(uvec4(2u, 2u, 2u, 2u), uvec4(0u, 0u, 0u, 1u), uvec4(2u, 5u, 34u, 0u)), uvec4(2u, 5u, 34u, 2u))) ? 1 : -1] array13;
  float[all(equal(max3(uvec4(2u, 2u, 2u, 2u), uvec4(1u, 1u, 1u, 1u), uvec4(1u, 2u, 5u, 34u)), uvec4(2u, 2u, 5u, 34u))) ? 1 : -1] array14;
  float[all(equal(max3(uvec4(2u, 2u, 2u, 2u), uvec4(2u, 2u, 2u, 2u), uvec4(0u, 1u, 2u, 5u)), uvec4(2u, 2u, 2u, 5u))) ? 1 : -1] array15;
  float[all(equal(max3(uvec4(2u, 2u, 2u, 2u), uvec4(2u, 5u, 5u, 5u), uvec4(34u, 0u, 1u, 2u)), uvec4(34u, 5u, 5u, 5u))) ? 1 : -1] array16;
  float[all(equal(max3(uvec4(2u, 2u, 2u, 2u), uvec4(5u, 5u, 34u, 34u), uvec4(5u, 34u, 0u, 1u)), uvec4(5u, 34u, 34u, 34u))) ? 1 : -1] array17;
  float[all(equal(max3(uvec4(2u, 2u, 2u, 5u), uvec4(34u, 34u, 34u, 0u), uvec4(2u, 5u, 34u, 0u)), uvec4(34u, 34u, 34u, 5u))) ? 1 : -1] array18;
  float[all(equal(max3(uvec4(5u, 5u, 5u, 5u), uvec4(0u, 0u, 0u, 0u), uvec4(1u, 2u, 5u, 34u)), uvec4(5u, 5u, 5u, 34u))) ? 1 : -1] array19;
  float[all(equal(max3(uvec4(5u, 5u, 5u, 5u), uvec4(1u, 1u, 1u, 1u), uvec4(0u, 1u, 2u, 5u)), uvec4(5u, 5u, 5u, 5u))) ? 1 : -1] array20;
  float[all(equal(max3(uvec4(5u, 5u, 5u, 5u), uvec4(1u, 2u, 2u, 2u), uvec4(34u, 0u, 1u, 2u)), uvec4(34u, 5u, 5u, 5u))) ? 1 : -1] array21;
  float[all(equal(max3(uvec4(5u, 5u, 5u, 5u), uvec4(2u, 2u, 5u, 5u), uvec4(5u, 34u, 0u, 1u)), uvec4(5u, 34u, 5u, 5u))) ? 1 : -1] array22;
  float[all(equal(max3(uvec4(5u, 5u, 5u, 5u), uvec4(5u, 5u, 5u, 34u), uvec4(2u, 5u, 34u, 0u)), uvec4(5u, 5u, 34u, 34u))) ? 1 : -1] array23;
  float[all(equal(max3(uvec4(5u, 5u, 5u, 5u), uvec4(34u, 34u, 34u, 34u), uvec4(1u, 2u, 5u, 34u)), uvec4(34u, 34u, 34u, 34u))) ? 1 : -1] array24;
  float[all(equal(max3(uvec4(34u, 34u, 34u, 34u), uvec4(0u, 0u, 0u, 0u), uvec4(0u, 1u, 2u, 5u)), uvec4(34u, 34u, 34u, 34u))) ? 1 : -1] array25;
  float[all(equal(max3(uvec4(34u, 34u, 34u, 34u), uvec4(0u, 1u, 1u, 1u), uvec4(34u, 0u, 1u, 2u)), uvec4(34u, 34u, 34u, 34u))) ? 1 : -1] array26;
  float[all(equal(max3(uvec4(34u, 34u, 34u, 34u), uvec4(1u, 1u, 2u, 2u), uvec4(5u, 34u, 0u, 1u)), uvec4(34u, 34u, 34u, 34u))) ? 1 : -1] array27;
  float[all(equal(max3(uvec4(34u, 34u, 34u, 34u), uvec4(2u, 2u, 2u, 5u), uvec4(2u, 5u, 34u, 0u)), uvec4(34u, 34u, 34u, 34u))) ? 1 : -1] array28;
  float[all(equal(max3(uvec4(34u, 34u, 34u, 34u), uvec4(5u, 5u, 5u, 5u), uvec4(1u, 2u, 5u, 34u)), uvec4(34u, 34u, 34u, 34u))) ? 1 : -1] array29;
  float[all(equal(max3(uvec4(34u, 34u, 34u, 34u), uvec4(34u, 34u, 34u, 34u), uvec4(0u, 1u, 2u, 5u)), uvec4(34u, 34u, 34u, 34u))) ? 1 : -1] array30;
  float[all(equal(max3(uvec4(34u, 0u, 0u, 0u), uvec4(34u, 0u, 0u, 0u), uvec4(34u, 0u, 1u, 2u)), uvec4(34u, 0u, 1u, 2u))) ? 1 : -1] array31;
  gl_FragColor = vec4(array0.length() + array1.length() + array2.length() + array3.length() + array4.length() + array5.length() + array6.length() + array7.length() + array8.length() + array9.length() + array10.length() + array11.length() + array12.length() + array13.length() + array14.length() + array15.length() + array16.length() + array17.length() + array18.length() + array19.length() + array20.length() + array21.length() + array22.length() + array23.length() + array24.length() + array25.length() + array26.length() + array27.length() + array28.length() + array29.length() + array30.length() + array31.length());
}
